==> quasar-1.8.5.jar: META-INF/resources/webjars/quasar/1.8.5/icon-set/line-awesome.js <==
export default {
  name: 'line-awesome',
  type: {
    positive: 'las la-check',
    negative: 'las la-exclamation-triangle',
    info: 'las la-info-circle',
    warning: 'las la-exclamation'
  },
  arrow: {
    up: 'las la-arrow-up',
    right: 'las la-arrow-right',
    down: 'las la-arrow-down',
    left: 'las la-arrow-left',
    dropdown: 'las la-caret-down'
  },
  chevron: {
    left: 'las la-chevron-left',
    right: 'las la-chevron-right'
  },
  colorPicker: {
    spectrum: 'las la-eye-dropper',
    tune: 'las la-sliders-h',
    palette: 'las la-swatchbook'
  },
  pullToRefresh: {
    icon: 'las la-sync-alt'
  },
  carousel: {
    left: 'las la-chevron-left',
    right: 'las la-chevron-right',
    navigationIcon: 'las la-circle',
    thumbnails: 'las la-th'
  },
  chip: {
    remove: 'las la-times-circle',
    selected: 'las la-check'
  },
  datetime: {
    arrowLeft: 'las la-chevron-left',
    arrowRight: 'las la-chevron-right',
    now: 'lar la-clock',
    today: 'lar la-calendar-check'
  },
  editor: {
    bold: 'las la-bold',
    italic: 'las la-italic',
    strikethrough: 'las la-strikethrough',
    underline: 'las la-underline',
    unorderedList: 'las la-list-ul',
    orderedList: 'las la-list-ol',
    subscript: 'las la-subscript',
    superscript: 'las la-superscript',
    hyperlink: 'las la-link',
    toggleFullscreen: 'las la-expand-arrows-alt',
    quote: 'las la-quote-right',
    left: 'las la-align-left',
    center: 'las la-align-center',
    right: 'las la-align-right',
    justify: 'las la-align-justify',
    print: 'las la-print',
    outdent: 'las la-outdent',
    indent: 'las la-indent',
    removeFormat: 'las la-eraser',
    formatting: 'las la-heading',
    fontSize: 'las la-text-height',
    align: 'las la-align-left',
    hr: 'lar la-minus-square',
    undo: 'las la-undo',
    redo: 'las la-redo',
    heading: 'las la-heading',
    code: 'las la-code',
    size: 'las la-text-height',
    font: 'las la-font',
    viewSource: 'las la-code'
  },
  expansionItem: {
    icon: 'las la-chevron-down',
    denseIcon: 'las la-caret-down'
  },
  fab: {
    icon: 'las la-plus',
    activeIcon: 'las la-times'
  },
  field: {
    clear: 'las la-times-circle',
    error: 'las la-exclamation-circle'
  },
  pagination: {
    first: 'las la-step-backward',
    prev: 'las la-chevron-left',
    next: 'las la-chevron-right',
    last: 'las la-step-forward'
  },
  rating: {
    icon: 'las la-star'
  },
  stepper: {
    done: 'las la-check',
    active: 'las la-pencil-alt',
    error: 'las la-exclamation-triangle'
  },
  tabs: {
    left: 'las la-chevron-left',
    right: 'las la-chevron-right',
    up: 'las la-chevron-up',
    down: 'las la-chevron-down'
  },
  table: {
    arrowUp: 'las la-arrow-up',
    warning: 'las la-exclamation-triangle',
    prevPage: 'las la-chevron-left',
    nextPage: 'las la-chevron-right'
  },
  tree: {
    icon: 'las la-play'
  },
  uploader: {
    done: 'las la-check',
    clear: 'las la-times',
    add: 'las la-plus-square',
    upload: 'las la-upload',
    removeQueue: 'las la-stream',
    removeUploaded: 'las la-clipboard-check'
  }
}

==> quasar-1.9.7.jar: META-INF/resources/webjars/quasar/1.9.7/icon-set/line-awesome.js <==
export default {
  name: 'line-awesome',
  type: {
    positive: 'las la-check',
    negative: 'las la-exclamation-triangle',
    info: 'las la-info-circle',
    warning: 'las la-exclamation'
  },
  arrow: {
    up: 'las la-arrow-up',
    right: 'las la-arrow-right',
    down: 'las la-arrow-down',
    left: 'las la-arrow-left',
    dropdown: 'las la-caret-down'
  },
  chevron: {
    left: 'las la-chevron-left',
    right: 'las la-chevron-right'
  },
  colorPicker: {
    spectrum: 'las la-eye-dropper',
    tune: 'las la-sliders-h',
    palette: 'las la-swatchbook'
  },
  pullToRefresh: {
    icon: 'las la-sync-alt'
  },
  carousel: {
    left: 'las la-chevron-left',
    right: 'las la-chevron-right',
    up: 'las la-chevron-up',
    down: 'las la-chevron-down',
    navigationIcon: 'las la-square'
  },
  chip: {
    remove: 'las la-times-circle',
    selected: 'las la-check'
  },
  datetime: {
    arrowLeft: 'las la-chevron-left',
    arrowRight: 'las la-chevron-right',
    now: 'lar la-clock',
    today: 'lar la-calendar-check'
  },
  editor: {
    bold: 'las la-bold',
    italic: 'las la-italic',
    strikethrough: 'las la-strikethrough',
    underline: 'las la-underline',
    unorderedList: 'las la-list-ul',
    orderedList: 'las la-list-ol',
    subscript: 'las la-subscript',
    superscript: 'las la-superscript',
    hyperlink: 'las la-link',
    toggleFullscreen: 'las la-expand-arrows-alt',
    quote: 'las la-quote-right',
    left: 'las la-align-left',
    center: 'las la-align-center',
    right: 'las la-align-right',
    justify: 'las la-align-justify',
    print: 'las la-print',
    outdent: 'las la-outdent',
    indent: 'las la-indent',
    removeFormat: 'las la-eraser',
    formatting: 'las la-heading',
    fontSize: 'las la-text-height',
    align: 'las la-align-left',
    hr: 'lar la-minus-square',
    undo: 'las la-undo',
    redo: 'las la-redo',
    heading: 'las la-heading',
    code: 'las la-code',
    size: 'las la-text-height',
    font: 'las la-font',
    viewSource: 'las la-code'
  },
  expansionItem: {
    icon: 'las la-chevron-down',
    denseIcon: 'las la-caret-down'
  },
  fab: {
    icon: 'las la-plus',
    activeIcon: 'las la-times'
  },
  field: {
    clear: 'las la-times-circle',
    error: 'las la-exclamation-circle'
  },
  pagination: {
    first: 'las la-step-backward',
    prev: 'las la-chevron-left',
    next: 'las la-chevron-right',
    last: 'las la-step-forward'
  },
  rating: {
    icon: 'las la-star'
  },
  stepper: {
    done: 'las la-check',
    active: 'las la-pencil-alt',
    error: 'las la-exclamation-triangle'
  },
  tabs: {
    left: 'las la-chevron-left',
    right: 'las la-chevron-right',
    up: 'las la-chevron-up',
    down: 'las la-chevron-down'
  },
  table: {
    arrowUp: 'las la-arrow-up',
    warning: 'las la-exclamation-triangle',
    prevPage: 'las la-chevron-left',
    nextPage: 'las la-chevron-right'
  },
  tree: {
    icon: 'las la-play'
  },
  uploader: {
    done: 'las la-check',
    clear: 'las la-times',
    add: 'las la-plus-square',
    upload: 'las la-upload',
    removeQueue: 'las la-stream',
    removeUploaded: 'las la-clipboard-check'
  }
}
